# -*- coding: utf-8 -*-

"""cli.validation
----------------------------------

Validation functions for CLI.

"""

import click


def validate_yaml_paths(ctx, param, value):
    if not value:
        raise click.BadParameter("Must provide at least one yaml path.")
    return value



# -*- coding: utf-8 -*-

import subprocess


def get_subprocess_output(command):
    """Call subprocess and return stdout normalized into Python string.
    """
    output = subprocess.check_output(command, shell=True)
    return output.rstrip().decode('UTF-8')



# -*- coding: utf-8 -*-

import yaml

from jinja2 import Environment
from jinja2 import PackageLoader
import click

from pyresume.cli.validation import validate_yaml_paths


@click.group()
def main():
    """ Console script for pyresume.
    """
    pass


@main.group()
def create():
    """ Create a resume of the specified type. The type is either "tex" by
    default or whatever is specified as the next subcommand.
    """
    pass


@create.command()
@click.argument('yaml_paths',
                nargs=-1,
                callback=validate_yaml_paths,
                type=click.Path(exists=True,
                                file_okay=True,
                                dir_okay=False,
                                readable=True,
                                resolve_path=True))
def tex(yaml_paths):
    """Generate LaTeX output.

    Using the resume data contained within the given yaml files, generate LaTeX
    output on stdout. Note that resume data in successive yaml files overrides
    that specified in earlier files.
    """
    env = Environment(
        trim_blocks=True,
        lstrip_blocks=True,
        loader=PackageLoader('pyresume', 'templates'),
    )
    template = env.get_template('standard.tex')

    resume_data = {}
    for path in yaml_paths:
        with open(path, "r") as f:
            yaml_data = yaml.load(f)
        resume_data.update(yaml_data)

    latex_string = template.render(**resume_data)
    click.echo(latex_string)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import find_packages
from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    'PyYAML==3.12',
    'jinja2==2.10',
]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='pyresume',
    version='0.1.3',
    description="Populate a predefined LaTeX template with contents defined in YAML to build your resume.",
    long_description=readme + '\n\n' + history,
    author="Wayne Warren",
    author_email='wayne.warren.s@gmail.com',
    url='https://github.com/waynr/pyresume',
    packages=find_packages('src'),
    package_dir={'':
                 'src'},
    entry_points={
        'console_scripts': [
            'pyresume=pyresume.cli:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    license="GNU General Public License v3",
    zip_safe=False,
    keywords='pyresume',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
